@@ -268,10 +268,15 @@ class DataRun:
 		Returns:
 			Unix timestamp in UTC timezone
 		"""
-		if self.singleWaves() is not None:
-			return self.singleWaves().getFileStartTime()[0]
-		elif self.coincWaves() is not None:
-			return self.coincWaves().getFileStartTime()[0]
+		#check if this data is in the parameter file
+		if self.parameterFile().startTime is not None:
+			#this should go off for HDF5 formatted files
+			return self.parameterFile().startTime
+		else: #if that data isn't there, move this to another dataset
+			if self.singleWaves() is not None:
+				return self.singleWaves().getFileStartTime()
+			elif self.coincWaves() is not None:
+				return self.coincWaves().getFileStartTime()
 		
 	def plotHitLocations(self, sourceFile = 'trigger', orig = False, **kwargs):
 		"""
